@@ -115,7 +115,9 @@ command commande[] = {
 	// extension to a higher priority in case two files with same basename
 	// exist (stat_file() manages that priority order for now).
 	{"log", 0, "log ", process_log}, /* logarifies current image */
+#ifndef WIN32
 	{"ls", 0, "ls ", process_ls},
+#endif
 	
 	{"mirrorx", 0, "mirrorx", process_mirrorx},
 	{"mirrory", 0, "mirrory", process_mirrory},
@@ -454,12 +456,9 @@ int process_wrecons(int nb){
 	}
 
 	for (i=0; i < nb_chan; i++) {
-		dir[i] = malloc(strlen(tmpdir) + strlen(File_Name_Transform[i]) + 2);
-		strcpy(dir[i], tmpdir);
-		strcat(dir[i], "/");
-		strcat(dir[i], File_Name_Transform[i]);
+		dir[i] = g_build_filename(tmpdir, File_Name_Transform[i], NULL);
 		wavelet_reconstruct_file (dir[i], coef, gfit.pdata[i]);
-		free(dir[i]);
+		g_free(dir[i]);
 	}
 
 	adjust_cutoff_from_updated_gfit();
@@ -491,7 +490,7 @@ int process_wavelet(int nb){
 		return 1;
 	}
 
-	if(Type_Transform != TO_PAVE_LINEAR && Type_Transform !=TO_PAVE_BSPLINE){
+	if(Type_Transform != TO_PAVE_LINEAR && Type_Transform != TO_PAVE_BSPLINE){
 		siril_log_message(_("Wavelet: type must be %d or %d\n"), TO_PAVE_LINEAR, TO_PAVE_BSPLINE);
 		return 1;
 	}
@@ -499,12 +498,9 @@ int process_wavelet(int nb){
 	Imag = f_vector_alloc (gfit.rx * gfit.ry);
 	
 	for (chan = 0; chan < nb_chan; chan++) {
-		dir[chan] = malloc(strlen(tmpdir) + strlen(File_Name_Transform[chan]) + 2);
-		strcpy(dir[chan], tmpdir);
-		strcat(dir[chan], "/");
-		strcat(dir[chan], File_Name_Transform[chan]);
+		dir[chan] = g_build_filename(tmpdir, File_Name_Transform[chan], NULL);
 		wavelet_transform_file (Imag, gfit.ry, gfit.rx, dir[chan], Type_Transform, Nbr_Plan, gfit.pdata[chan]);
-		free(dir[chan]);
+		g_free(dir[chan]);
 	}
 	
 	free (Imag);
@@ -519,31 +515,31 @@ int process_log(int nb){
 	return 0;
 }
 
+#ifndef WIN32
 int process_ls(int nb){
 	struct dirent **list;
-	char filename[256], *path;
+	gchar *path = NULL;
 	
-	filename[0]='\0';
 	/* If a path is given in argument */
-	if (nb>1){
-		if (word[1][0]!='\0'){	
+	if (nb > 1) {
+		if (word[1][0] != '\0') {
 			/* Absolute path */
-			if(word[1][0]=='/' || word[1][0]=='~'){
+			if (word[1][0] == G_DIR_SEPARATOR || word[1][0] == '~') {
+				char filename[256];
+				
 				strncpy(filename, word[1], 250);
 				filename[250] = '\0';
 				expand_home_in_filename(filename, 256);
+				path = g_build_filename(filename, NULL);
 			}
 			/* Relative path */
 			else {
-				strcpy(filename, com.wd);
-				strcat(filename, "/");
-				strcat(filename, word[1]);
-			}	
-			path = strdup(filename);
+				path = g_build_filename(com.wd, word[1], NULL);
+			}
 		}
 		/* Should not happen */
 		else {
-			printf("Cannot list files in %s\n", filename);
+			printf("Cannot list files in %s\n", word[1]);
 			return 1;
 		}
 	}
@@ -555,37 +551,37 @@ int process_ls(int nb){
 		}
 		path = strdup(com.wd);
 	}
-	if (!path) {
+	if (path == NULL) {
 		siril_log_message(_("Siril cannot open the directory.\n"));
 		return 1;
 	}
 
-#ifdef WIN32
-	ListDirectoryContents(path);
-#else
 	int i, n;
 
 	n = scandir(path, &list, 0, alphasort);
-	if (n < 0)
+	if (n < 0) {
 		perror("scandir");
+		siril_log_message(_("Siril cannot open the directory.\n"));
+		g_free(path);
+		return 1;
+	}
 
 	/* List the entries */
 	for (i = 0; i < n; ++i) {
 		struct stat entrystat;
-		char file_path[256];
+		gchar *filename;
 		const char *ext;
 		if (list[i]->d_name[0] == '.')
 			continue; /* no hidden files */
-		if (filename[0] != '\0')
-			sprintf(file_path, "%s/%s", filename, list[i]->d_name);
-		else {
-			sprintf(file_path, "%s", list[i]->d_name);
-		}
 
-		if (lstat(file_path, &entrystat)) {
+		filename = g_build_filename(path, list[i]->d_name, NULL);
+
+		if (lstat(filename, &entrystat)) {
 			perror("stat");
+			g_free(filename);
 			break;
 		}
+		g_free(filename);
 		if (S_ISLNK(entrystat.st_mode)) {
 			siril_log_color_message(_("Link: %s\n"), "bold", list[i]->d_name);
 			continue;
@@ -613,12 +609,12 @@ int process_ls(int nb){
 	for (i = 0; i < n; i++)
 		free(list[i]);
 	free(list);
-#endif
 	siril_log_message(_("********* END OF THE LIST *********\n"));
-	free(path);
+	g_free(path);
 
 	return 0;
 }
+#endif
 
 int	process_mirrorx(int nb){
 	mirrorx(&gfit, TRUE);
@@ -1018,9 +1014,8 @@ int process_findhot(int nb){
 	deviant_pixel *dev = find_deviant_pixels(&gfit, sig, &icold, &ihot);
 	siril_log_message(_("%ld cold and %ld hot pixels\n"), icold, ihot);
 
-	FILE* cosme_file = NULL;
 	sprintf(filename, "%s.lst", word[1]);
-	cosme_file = fopen(filename, "w");
+	FILE *cosme_file = fopen(filename, "w");
 	if (cosme_file == NULL) {
 		siril_log_message(_("Cannot open file: %s\n"), filename);
 		free(dev);
@@ -1642,6 +1637,7 @@ int processcommand(const char *line) {
 		len = strlen(line);
 		parseLine(myline, len, &wordnb);
 		if (executeCommand(wordnb)) {
+			free(myline);
 			return 1;
 		}
 		free(myline);
