@@ -21,8 +21,9 @@ int	readfits(const char *filename, fits *fit, char *realname);
 char*	list_header(fits *fit);
 void	clearfits(fits *);
 void	report_fits_error(int status);
-int	readfits_partial(const char *filename, int layer, fits *fit, const rectangle *area);
+int	readfits_partial(const char *filename, int layer, fits *fit, const rectangle *area, gboolean read_date);
 int	read_opened_fits_partial(sequence *seq, int layer, int index, WORD *buffer, const rectangle *area);
+int	fits_get_date_obs(const char *name, fits *f);
 int 	savefits(const char *, fits *);
 void 	save_fits_header(fits *);
 int	copyfits(fits *from, fits *to, unsigned char oper, int layer);
@@ -102,7 +103,7 @@ gboolean isrgb(fits *fit);
 gboolean ends_with(const char *str, const char *ending);
 int	get_extension_index(const char *filename);
 int	is_readable_file(const char *filename);
-int	stat_file(const char *filename2, image_type *type, char *realname);
+int	stat_file(const char *filename2, image_type *type, char **realname);
 const char *get_filename_ext(const char *filename);
 
 int	changedir(const char *dir);
@@ -119,7 +120,12 @@ char*	remove_ext_from_filename(const char *basename);
 char*	str_append(char** data, const char* newdata);
 char*	format_basename(char *root);
 float	computePente(WORD *lo, WORD *hi);
-void load_css_style_sheet (char *path);
+void	load_css_style_sheet (char *path);
+double	encodeJD(dateTime dt);
+#ifdef WIN32
+int ListDirectoryContents(const char *sDir);
+int ListSequences(const char *sDir, const char *sequence_name_to_select, GtkComboBoxText *seqcombo, int *index_of_seq_to_load);
+#endif
 
 /****************** quantize.h ***************/
 int fits_img_stats_ushort(WORD *array, long nx, long ny, int nullcheck,
@@ -205,41 +211,6 @@ gpointer BandingEngineThreaded(gpointer p);
 int BandingEngine(fits *fit, double sigma, double amount, gboolean protect_highlights, gboolean applyRotation);
 gpointer noise(gpointer p);
 
-/****************** sequence.h ******************/
-int	read_single_sequence(char *realname, int imagetype);
-int	seqsetnum(int image_number);
-int	check_seq(int force);
-int	check_only_one_film_seq(char* name);
-int	set_seq(const char *);
-char *	seq_get_image_filename(sequence *seq, int index, char *name_buf);
-int	seq_read_frame(sequence *seq, int index, fits *dest);
-int	seq_read_frame_part(sequence *seq, int layer, int index, fits *dest, const rectangle *area);
-int	seq_load_image(sequence *seq, int index, fits *dest, gboolean load_it);
-int	seq_open_image(sequence *seq, int index);
-void	seq_close_image(sequence *seq, int index);
-int	seq_opened_read_region(sequence *seq, int layer, int index, WORD *buffer, const rectangle *area);
-void	set_fwhm_star_as_star_list(sequence *seq);
-void	set_fwhm_star_as_star_list_with_layer(sequence *seq, int layer);
-char *	fit_sequence_get_image_filename(sequence *seq, int index, char *name_buffer, gboolean add_fits_ext);
-char *	get_possible_image_filename(sequence *seq, int image_number, char *name_buffer);
-int	get_index_and_basename(const char *filename, char **basename, int *index, int *fixed);
-void	initialize_sequence(sequence *seq, gboolean is_zeroed);
-void	free_sequence(sequence *seq, gboolean free_seq_too);
-void	sequence_free_preprocessing_data(sequence *seq);
-gboolean sequence_is_loaded();
-int	sequence_processing(sequence *seq, sequence_proc process, int layer, gboolean run_in_thread, gboolean run_in_parallel, void *arg);
-int	seqprocess_fwhm(sequence *seq, int seq_layer, int frame_no, fits *fit, rectangle *source_area, void *arg);
-int	do_fwhm_sequence_processing(sequence *seq, int layer, gboolean print_psf, gboolean follow_star, gboolean run_in_thread, gboolean for_registration);
-void	check_or_allocate_regparam(sequence *seq, int layer);
-sequence *create_internal_sequence(int size);
-void	internal_sequence_set(sequence *seq, int index, fits *fit);
-int	internal_sequence_find_index(sequence *seq, fits *fit);
-gpointer crop_sequence(gpointer p);
-gboolean sequence_is_rgb(sequence *seq);
-imstats* seq_get_imstats(sequence *seq, int index, fits *the_image, int option);
-void	enforce_area_in_image(rectangle *area, sequence *seq);
-void	update_export_crop_label();
-
 /****************** seqfile.h ******************/
 sequence * readseqfile(const char *name);
 int	writeseqfile(sequence *seq);
