@@ -604,6 +604,14 @@ struct image_stats {
 	char layername[6];
 };
 
+typedef struct Homo {
+	double h00, h01, h02;
+	double h10, h11, h12;
+	double h20, h21, h22;
+	int pair_matched;
+	int Inliers;
+} Homography;
+
 #if 0
 /* TODO: this structure aims to allow the composition of several 1-channel images and make
  * more easy the management of RGB compositing */
