@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -29,7 +29,7 @@ void notify_new_photometry();
 void free_photometry_set(sequence *seq, int set);
 
 typedef struct plot_data_struct {
-	struct kpair *data;
+	struct kpair *data, *err;
 	int nb;
 	struct plot_data_struct *next;
 } pldata;
