@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 #include "core/siril.h"
 #include "core/proto.h"
 #include "gui/callbacks.h"
+#include "io/sequence.h"
 #include "algos/PSF.h"
 #include "registration/registration.h"	// for update_reg_interface
 #include "stacking/stacking.h"	// for update_stack_interface
@@ -212,15 +213,19 @@ void sequence_list_change_selection_index(int index) {
 void sequence_list_change_current() {
 	GtkTreeIter iter;
 	gboolean valid;
-	gint row_count = 0;
 
 	get_list_store();
 	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(list_store), &iter);
 	while (valid) {
+		gint index = 0;
+		GValue value = G_VALUE_INIT;
+
+		gtk_tree_model_get_value (GTK_TREE_MODEL(list_store), &iter, COLUMN_INDEX, &value);
+		index = g_value_get_int(&value);
+		g_value_unset(&value);
 		gtk_list_store_set(list_store, &iter,
-				COLUMN_CURRENT, (row_count == com.seq.current) ? 800 : 400,
+				COLUMN_CURRENT, (index == com.seq.current) ? 800 : 400,
 				-1);
-		row_count++;
 		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(list_store), &iter);
 	}
 }
