@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -217,11 +217,17 @@ static int randPixel(int nb_pixels) {
 
 static int *randomIndex(int n) {
 	srand(time(NULL));
-	int *index = malloc(n * sizeof (int));
+	int *index;
 	int i = 0;
 	int x = 0;
 	int tmp = 0;
 
+	index = calloc(n, sizeof (int));
+	if (index == NULL) {
+		printf("alloc error: randomIndex\n");
+		return NULL;
+	}
+
 	/* make index */
 	for (i = 0; i < n; i++) {
 		index[i] = i;
@@ -262,6 +268,9 @@ int film_read_frame(struct film_struct *film, int frame_no, fits *fit) {
 		if (frame_no == 0) {
 			int pixel_tested = 0, n = 0;
 			int *randIndex = randomIndex(nb_pixels * 3);
+			if (randIndex == NULL) {
+				return FILM_ERROR;
+			}
 			do {
 				int px = randIndex[n];
 				px = px - (px % 3);
