@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -32,6 +32,7 @@
 
 #include "core/siril.h"
 #include "io/ser.h"
+#include "io/sequence.h"
 #include "core/proto.h"
 #include "gui/callbacks.h"
 #if defined(HAVE_FFMS2_1) || defined(HAVE_FFMS2_2)
@@ -382,10 +383,15 @@ int buildseqfile(sequence *seq, int force_recompute) {
 		return 0;
 	}
 
-	filename = malloc(strlen(seq->seqname)+20);
+	filename = malloc(strlen(seq->seqname) + 20);
+	if (filename == NULL) {
+		printf("alloc error: buildseqfile\n");
+		return 1;
+	}
 	if (seq->type == SEQ_REGULAR) {
 		get_possible_image_filename(seq, seq->beg, filename);
 		// check if the sequence begins at first_index
+
 		if (stat_file(filename, &imagetype, NULL) || imagetype != TYPEFITS) {
 			siril_log_message(_("The sequence %s doesn't start at the frame number %d"
 					" with the specified fixed size index (%d). Cannot load.\n"),
@@ -426,12 +432,14 @@ int buildseqfile(sequence *seq, int force_recompute) {
 				seq->imgparam[seq->number].filenum = i;
 				seq->imgparam[seq->number].incl = SEQUENCE_DEFAULT_INCLUDE;
 				seq->imgparam[seq->number].stats = NULL;
+				seq->imgparam[seq->number].date_obs = NULL;
 				seq->number++;
 			}
 		} else {
 			seq->imgparam[i].filenum = i;
 			seq->imgparam[i].incl = SEQUENCE_DEFAULT_INCLUDE;
 			seq->imgparam[i].stats = NULL;
+			seq->imgparam[i].date_obs = NULL;
 		}
 	}
 #if SEQUENCE_DEFAULT_INCLUDE == TRUE
