@@ -72,7 +72,7 @@ struct ser_struct {
 	uint64_t ts_min, ts_max;// min and max timestamp
 	double fps;				// frame rate
 
-	off_t filesize;			// size of the file
+	int64_t filesize;			// size of the file
 
 	// internal representations of header data
 	ser_pixdepth byte_pixel_depth;	// more useful representation of the bit_pixel_depth
