@@ -29,6 +29,7 @@
 #endif
 #ifdef WIN32
 #include <windows.h>
+#include <tchar.h>
 #endif
 #include <unistd.h>
 #include <signal.h>
@@ -85,7 +86,6 @@ static void set_osx_integration(GtkosxApplication *osx_app, gchar *siril_path) {
 	GtkWidget *help_menu = lookup_widget("help1");
 	GtkWidget *sep;
 	GdkPixbuf *icon;
-	GString *icon_str;
 	gchar *icon_path;
 	
 	g_signal_connect(osx_app, "NSApplicationOpenFile", G_CALLBACK(osx_open_file), NULL);
@@ -103,11 +103,8 @@ static void set_osx_integration(GtkosxApplication *osx_app, gchar *siril_path) {
 
 	gtk_widget_hide(file_quit_menu_item);
 	gtk_widget_hide(help_menu);
-
-	icon_str = g_string_new(siril_path);
-	g_string_append(icon_str, "pixmaps/siril_1.svg");
 	
-	icon_path = g_string_free(icon_str, FALSE);
+	icon_path = g_build_filename(siril_path, "pixmaps/siril_1.svg", NULL);
 	icon = gdk_pixbuf_new_from_file(icon_path, NULL);
 	gtkosx_application_set_dock_icon_pixbuf(osx_app, icon);
 		
@@ -118,13 +115,15 @@ static void set_osx_integration(GtkosxApplication *osx_app, gchar *siril_path) {
 #endif
 
 char *siril_sources[] = {
-	"",
-#if (defined(__APPLE__) && defined(__MACH__))
-	"",
+#ifdef WIN32
+    "../share/siril",
+#elif (defined(__APPLE__) && defined(__MACH__))
+	"/tmp/siril/Contents/Resources/share/siril/",
 #endif
 	PACKAGE_DATA_DIR"/",
 	"/usr/share/siril/",
-	"/usr/local/share/siril/"
+	"/usr/local/share/siril/",
+	""
 };
 
 void usage(const char *command) {
@@ -150,24 +149,26 @@ int main(int argc, char *argv[]) {
 	char *cwd_orig = NULL;
 	gboolean forcecwd = FALSE;
 	char *cwd_forced = NULL;
-#if (defined(__APPLE__) && defined(__MACH__))
-	int ret;
-	pid_t pid;
-	char path[PROC_PIDPATHINFO_MAXSIZE];
-#endif
 	
 #ifdef WIN32
 	_putenv_s("LC_NUMERIC", "C");
+    setlocale( LC_ALL, "" );
+
+	/* for translation */
+    gchar *localedir = g_build_filename( _getcwd( 0, 0 ), "\\..\\share\\locale", NULL);
+	bindtextdomain(PACKAGE, g_win32_locale_filename_from_utf8 ( localedir ) );
+    bind_textdomain_codeset(PACKAGE, "UTF-8");
+	textdomain(PACKAGE);
 #else
 	setenv("LC_NUMERIC", "C", 1);		// avoid possible bugs using french separator ","
+	/* for translation */
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	textdomain(PACKAGE);
 #endif
 	opterr = 0;
 	memset(&com, 0, sizeof(struct cominf));	// needed?
 	com.initfile = NULL;
 	
-	/* for translation */
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
 
 	/* Caught signals */
 	signal(SIGINT, signal_handled);
@@ -222,40 +223,22 @@ int main(int argc, char *argv[]) {
 
 	gtk_init (&argc, &argv);
 
-#if (defined(__APPLE__) && defined(__MACH__))
-	pid = getpid();
-	ret = proc_pidpath ( pid, path, sizeof(path));
-	if ( ret ) {
-		int l;
-		char* sp;
-		sp = strrchr ( path, '/' );
-		sp -= 5;
-		*sp = 0;
-		l = strlen ( path );
-		if (( l + 10 ) < PROC_PIDPATHINFO_MAXSIZE ) {
-			( void ) strcat ( path, "Resources/" );
-			siril_sources[1] = path;
-		}
-	}
-#endif
-
 	/* try to load the glade file, from the sources defined above */
 	builder = gtk_builder_new();
 	i = 0;
 	do {
 		GError *err = NULL;
-		GString *pathStr = g_string_new (siril_sources[i]);
-		g_string_append(pathStr, GLADE_FILE);
-		gchar *path = g_string_free (pathStr, FALSE);
+        gchar *gladefile;
 
-		if (gtk_builder_add_from_file (builder, path, &err)) {
-			fprintf(stdout, _("Successfully loaded '%s%s'\n"), siril_sources[i], GLADE_FILE);
-			g_free(path);
+        gladefile = g_build_filename (siril_sources[i], GLADE_FILE, NULL);
+		if (gtk_builder_add_from_file (builder, gladefile, &err)) {
+			fprintf(stdout, _("Successfully loaded '%s'\n"), gladefile);
+			g_free(gladefile);
 			break;
 		}
 		fprintf (stderr, _("%s. Looking into another directory...\n"), err->message);
-		g_free(path);
 		g_error_free(err);
+		g_free(gladefile);
 		i++;
 	} while (i < sizeof(siril_sources)/sizeof(char *));
 	if (i == sizeof(siril_sources) / sizeof(char *)) {
