@@ -29,12 +29,23 @@
 #include <iomanip>
 #include <opencv2/core/core.hpp>
 #include <opencv2/imgproc/imgproc.hpp>
+#include "opencv2/core/version.hpp"
+#if CV_MAJOR_VERSION == 2
+#include "opencv/findHomography/calib3d.hpp"
+#else
+#include <opencv2/calib3d.hpp>
+#endif
+
 #include "core/siril.h"
 #include "core/proto.h"
 #include "registration/matching/misc.h"
+#include "registration/matching/atpmatch.h"
 #include "opencv.h"
 #include "opencv/ecc/ecc.h"
 
+
+#define defaultRANSACReprojThreshold 3
+
 using namespace cv;
 
 static WORD *fits_to_bgrbgr(fits *image) {
@@ -60,8 +71,8 @@ int cvResizeGaussian_data8(uint8_t *dataIn, int rx, int ry, uint8_t *dataOut,
 	for (int i = 0; i < toX * toY * chan; i++)
 		dataOut[i] = (uint8_t) out.data[i];
 
-	in = Mat();
-	out = Mat();
+	in.release();
+	out.release();
 	return 0;
 }
 
@@ -109,8 +120,11 @@ int cvResizeGaussian(fits *image, int toX, int toY, int interpolation) {
 		image->pdata[2] = image->data + (toX * toY) * 2;
 	}
 	delete[] bgrbgr;
-	in = Mat();
-	out = Mat();
+	in.release();
+	out.release();
+	channel[0].release();
+	channel[1].release();
+	channel[2].release();
 	return 0;
 }
 
@@ -182,40 +196,87 @@ int cvRotateImage(fits *image, double angle, int interpolation, int cropped) {
 
 	/* free data */
 	delete[] bgrbgr;
-	in = Mat();
-	out = Mat();
+	in.release();
+	out.release();
+	channel[0].release();
+	channel[1].release();
+	channel[2].release();
 	return 0;
 }
 
-int cvTransformImage(fits *image, TRANS trans, int interpolation) {
+int cvCalculH(s_star *star_array_img,
+		struct s_star *star_array_ref, int n, Homography *Hom) {
+
+	std::vector<Point2f> ref;
+	std::vector<Point2f> img;
+	Mat mask;
+	int i;
+
+	/* build vectors with lists of stars. */
+	for (i = 0; i < n; i++) {
+		ref.push_back(Point2f(star_array_ref[i].x, star_array_ref[i].y));
+		img.push_back(Point2f(star_array_img[i].x, star_array_img[i].y));
+	}
+
+	Mat H = findHomography(img, ref, CV_RANSAC, defaultRANSACReprojThreshold, mask);
+	if (countNonZero(H) < 1) {
+		return 1;
+	}
+	Hom->Inliers = countNonZero(mask);
+
+	Hom->h00 = H.at<double>(0, 0);
+	Hom->h01 = H.at<double>(0, 1);
+	Hom->h02 = H.at<double>(0, 2);
+	Hom->h10 = H.at<double>(1, 0);
+	Hom->h11 = H.at<double>(1, 1);
+	Hom->h12 = H.at<double>(1, 2);
+	Hom->h20 = H.at<double>(2, 0);
+	Hom->h21 = H.at<double>(2, 1);
+    Hom->h22 = H.at<double>(2, 2);
+
+	mask.release();
+	H.release();
+	return 0;
+}
+
+int cvTransformImage(fits *image, point ref, Homography Hom, int interpolation) {
 	assert(image->data);
 	assert(image->rx);
 	assert(image->ry);
 
-	int ndata = image->rx * image->ry;
-
+	int ndata = ref.x * ref.y;
+	WORD *newdata;
 	WORD *bgrbgr = fits_to_bgrbgr(image);
 
 	Mat in(image->ry, image->rx, CV_16UC3, bgrbgr);
-	Mat out(image->ry, image->rx, CV_16UC3);
+	Mat out(ref.y, ref.x, CV_16UC3);
+	Mat H = Mat::eye(3, 3, CV_64FC1);
 
-	double angle = -atan2(trans.c, trans.b);
-	double s = sqrt(trans.b * trans.b + trans.c * trans.c);
+	H.at<double>(0, 0) = Hom.h00;
+	H.at<double>(0, 1) = Hom.h01;
+	H.at<double>(0, 2) = Hom.h02;
+	H.at<double>(1, 0) = Hom.h10;
+	H.at<double>(1, 1) = Hom.h11;
+	H.at<double>(1, 2) = Hom.h12;
+	H.at<double>(2, 0) = Hom.h20;
+	H.at<double>(2, 1) = Hom.h21;
+	H.at<double>(2, 2) = Hom.h22;
 
-    // http://en.wikipedia.org/wiki/Transformation_matrix#Affine_transformations
-	Mat transform = Mat::eye(2, 3, CV_64FC1);
-	transform.at<double>(0, 0) = s * cos(angle);
-	transform.at<double>(0, 1) = -s * sin(angle);
-	transform.at<double>(1, 0) = s * sin(angle);
-	transform.at<double>(1, 1) = s * cos(angle);
-	transform.at<double>(0, 2) = trans.a;	// shift dx
-	transform.at<double>(1, 2) = trans.d;	// shift dy
-
-	warpAffine(in, out, transform, in.size(), interpolation);
+	warpPerspective(in, out, H, Size(ref.x, ref.y), interpolation);
 
 	Mat channel[3];
 	split(out, channel);
 
+	if (image->ry != ref.y || image->rx != ref.x) {
+		newdata = (WORD*) realloc(image->data,
+				ref.x * ref.y * sizeof(WORD) * image->naxes[2]);
+		if (!newdata) {
+			free(newdata);
+			return 1;
+		}
+		image->data = newdata;
+	}
+
 	memcpy(image->data, channel[2].data, ndata * sizeof(WORD));
 	if (image->naxes[2] == 3) {
 		memcpy(image->data + ndata, channel[1].data, ndata * sizeof(WORD));
@@ -238,9 +299,12 @@ int cvTransformImage(fits *image, TRANS trans, int interpolation) {
 
 	/* free data */
 	delete[] bgrbgr;
-	in = Mat();
-	out = Mat();
-	transform = Mat();
+	in.release();
+	out.release();
+	channel[0].release();
+	channel[1].release();
+	channel[2].release();
+	H.release();
 	return 0;
 }
 
@@ -314,8 +378,11 @@ int cvComputeFinestScale(fits *image) {
 
 	/* free data */
 	delete[] bgrbgr;
-	in = Mat();
-	out = Mat();
+	channel[0].release();
+	channel[1].release();
+	channel[2].release();
+	in.release();
+	out.release();
 
 	return 0;
 }
