@@ -491,28 +491,35 @@ int register_shift_fwhm(struct registration_args *args) {
 
 #ifdef HAVE_OPENCV
 
-static void _print_result(TRANS *trans, float FWHMx, float FWHMy) {
-	double rotation, scale;
+static void _print_result(Homography *H, float FWHMx, float FWHMy) {
+	double rotation, scale, scaleX, scaleY;
 	point shift;
+	double inliers;
 
-	switch (trans->order) {
-	case AT_TRANS_LINEAR:
-		rotation = -atan2(trans->c, trans->b);
-		shift.x = trans->a;
-		shift.y = -trans->d;
-		scale = sqrt(trans->b * trans->b + trans->c * trans->c);
-		siril_log_color_message(_("Matching stars: done\n"), "green");
-		siril_log_message(_("%d pair matches.\n"), trans->nr);
-		siril_log_message(_("scale:%*.3f\n"), 13, scale);
-		siril_log_message(_("rotation:%+*.2f deg\n"), 9, rotation * 180 / M_PI);
-		siril_log_message(_("dx:%+*.2f px\n"), 15, shift.x);
-		siril_log_message(_("dy:%+*.2f px\n"), 15, shift.y);
-		siril_log_message(_("FWHMx:%*.2f px\n"), 12, FWHMx);
-		siril_log_message(_("FWHMy:%*.2f px\n"), 12, FWHMy);
-		break;
-	default:
-		siril_log_color_message(_("Not handled yet\n"), "red");
-	}
+	siril_log_color_message(_("Matching stars: done\n"), "green");
+	siril_log_message(_("%d pair matches.\n"), H->pair_matched);
+	inliers = 1.0 - ((((double) H->pair_matched - (double) H->Inliers)) / (double) H->pair_matched);
+	siril_log_message(_("Inliers:%*.3f\n"), 11, inliers);
+
+	// scale
+	scaleX = sqrt(H->h00 * H->h00 + H->h01 * H->h01);
+	scaleY = sqrt(H->h10 * H->h10 + H->h11 * H->h11);
+	scale = (scaleX + scaleY) * 0.5;
+	siril_log_message(_("scaleX:%*.3f\n"), 12, scaleX);
+	siril_log_message(_("scaleY:%*.3f\n"), 12, scaleY);
+	siril_log_message(_("scale:%*.3f\n"), 13, scale);
+
+	// rotation
+	rotation = -atan2(H->h01, H->h00);
+	siril_log_message(_("rotation:%+*.2f deg\n"), 9, rotation * 180 / M_PI);
+
+	// translation
+	shift.x = -H->h02;
+	shift.y = -H->h12;
+	siril_log_message(_("dx:%+*.2f px\n"), 15, shift.x);
+	siril_log_message(_("dy:%+*.2f px\n"), 15, shift.y);
+	siril_log_message(_("FWHMx:%*.2f px\n"), 12, FWHMx);
+	siril_log_message(_("FWHMy:%*.2f px\n"), 12, FWHMy);
 }
 
 int register_star_alignment(struct registration_args *args) {
@@ -522,15 +529,16 @@ int register_star_alignment(struct registration_args *args) {
 	float nb_frames, cur_nb;
 	float FWHMx, FWHMy;
 	fitted_PSF **stars, **refstars;
-	TRANS trans;
+	Homography H;
 	regdata *current_regdata;
 	starFinder sf;
 	fits fit;
+	point ref;
 	struct ser_struct *new_ser = NULL;
 
 	memset(&fit, 0, sizeof(fits));
 	memset(&sf, 0, sizeof(starFinder));
-	memset(&trans, 0, sizeof(TRANS));
+	memset(&H, 0, sizeof(Homography));
 
 	if (!args->seq->regparam) {
 		fprintf(stderr, "regparam should have been created before\n");
@@ -588,6 +596,9 @@ int register_star_alignment(struct registration_args *args) {
 	}
 	redraw(com.cvport, REMAP_NONE); // draw stars
 
+	ref.x = fit.rx;
+	ref.y = fit.ry;
+
 	/* we copy com.stars to refstars in case user take a look to another image of the sequence
 	 * that would destroy com.stars
 	 */
@@ -601,18 +612,12 @@ int register_star_alignment(struct registration_args *args) {
 		i++;
 	}
 
-#ifdef DEBUG
-	FILE *pfile;
-
-	pfile = fopen("ref.txt", "w+");
-	fprintf(pfile, "REFERENCE IMAGE\n");
-	for (i = 0; i < MAX_STARS_FITTED; i++) {
-		fprintf(pfile, "%.3lf\t%.3lf\t%.3lf\n",
-				refstars[i]->xpos, refstars[i]->ypos, refstars[i]->mag);
+	if (sf.nb_stars > MAX_STARS_FITTED) {
+		fitted_stars = MAX_STARS_FITTED;
+		siril_log_color_message(_("Reference Image: Limiting to %d brightest stars\n"), "green", MAX_STARS_FITTED);
+	} else {
+		fitted_stars = sf.nb_stars;
 	}
-	fclose(pfile);
-#endif
-	fitted_stars = (sf.nb_stars > MAX_STARS_FITTED) ? MAX_STARS_FITTED : sf.nb_stars;
 	FWHM_average(refstars, &FWHMx, &FWHMy, fitted_stars);
 	siril_log_message(_("FWHMx:%*.2f px\n"), 12, FWHMx);
 	siril_log_message(_("FWHMy:%*.2f px\n"), 12, FWHMy);
@@ -630,7 +635,7 @@ int register_star_alignment(struct registration_args *args) {
 
 		new_ser = malloc(sizeof(struct ser_struct));
 
-		const char *ptr = strrchr(args->seq->seqname, '/');
+		const char *ptr = strrchr(args->seq->seqname, G_DIR_SEPARATOR);
 		if (ptr)
 			snprintf(dest, 255, "%s%s.ser", args->prefix, ptr + 1);
 		else
@@ -684,24 +689,17 @@ int register_star_alignment(struct registration_args *args) {
 						continue;
 					}
 
-#ifdef DEBUG
-					FILE *pfile2;
-
-					pfile2 = fopen("im.txt", "w+");
-					fprintf(pfile2, "IMAGE %d\n", frame);
-					for (i = 0; i < MAX_STARS_FITTED; i++) {
-						fprintf(pfile2, "%.3lf\t%.3lf\t%.3lf\n", stars[i]->xpos,
-								stars[i]->ypos, stars[i]->mag);
+					if (sf.nb_stars > fitted_stars) {
+						if (sf.nb_stars > MAX_STARS_FITTED) {
+							siril_log_color_message(_("Target Image: Limiting to %d brightest stars\n"), "green", MAX_STARS_FITTED);
+						}
+						nbpoints = fitted_stars;
+					}
+					else {
+						nbpoints = sf.nb_stars;
 					}
-					fprintf(pfile2, "\n\n", frame);
-					fclose(pfile2);
 
-#endif
-
-					nbpoints = (sf.nb_stars < fitted_stars) ?
-						sf.nb_stars : fitted_stars;
-
-					if (star_match(stars, refstars, nbpoints, &trans)) {
+					if (new_star_match(stars, refstars, nbpoints, &H)) {
 						siril_log_color_message(_("Cannot perform star matching. Image %d skipped\n"),
 								"red", frame);
 						args->new_total--;
@@ -715,22 +713,12 @@ int register_star_alignment(struct registration_args *args) {
 					}
 
 					FWHM_average(stars, &FWHMx, &FWHMy, nbpoints);
-					_print_result(&trans, FWHMx, FWHMy);
+					_print_result(&H, FWHMx, FWHMy);
 					current_regdata[frame].fwhm = FWHMx;
 
 					if (!args->translation_only) {
 						fits_flip_top_to_bottom(&fit);	// this is because in cvTransformImage, rotation center point is at (0, 0)
-
-						/* An alternative method for generating an improved rotation: Basically we apply the operation to an image
-						 * that is at least twice (or more) the size of the final image size wanted. After rotating the image,
-						 * the image is resized down to its final size so as to produce a very sharp lines,
-						 * edges, and much cleaner looking fonts. */
-						cvResizeGaussian(&fit, fit.rx * SUPER_SAMPLING, fit.ry * SUPER_SAMPLING, OPENCV_CUBIC);
-						trans.a *= SUPER_SAMPLING;
-						trans.d *= SUPER_SAMPLING;
-						cvTransformImage(&fit, trans, args->interpolation);
-						cvResizeGaussian(&fit, fit.rx / SUPER_SAMPLING, fit.ry / SUPER_SAMPLING, OPENCV_CUBIC);
-
+						cvTransformImage(&fit, ref, H, args->interpolation);
 						fits_flip_top_to_bottom(&fit);
 					}
 
@@ -755,8 +743,8 @@ int register_star_alignment(struct registration_args *args) {
 					args->imgparam[frame - failed - skipped].incl = SEQUENCE_DEFAULT_INCLUDE;
 					args->regparam[frame - failed - skipped].fwhm = current_regdata[frame].fwhm;	// not FWHMx because of the ref frame
 				} else {
-					current_regdata[frame].shiftx = trans.a;
-					current_regdata[frame].shifty = -trans.d;
+					current_regdata[frame].shiftx = +H.h02;
+					current_regdata[frame].shifty = -H.h12;
 					args->seq->imgparam[frame].incl = SEQUENCE_DEFAULT_INCLUDE;
 				}
 
